.. PyRemoteData documentation master file, created by
   sphinx-quickstart on Mon Jan 29 13:37:16 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

The documentation is a work in progress!

Welcome to PyRemoteData's documentation!
========================================

PyRemoteData is a Python package for downloading and managing remote data on servers supporting the SFTP protocol. 

It has primarily been developed to facilitate high-throughput data transfer in high-bandwidth/high-latency situations (over the internet) for machine learning applications, but can be used for any application requiring remote data access.

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   implicit_mount
   config
   dataloader


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


